<?php

namespace App\Http\Controllers;

use App\Providers\AttachmentServiceProvider;
use App\Providers\GenericHelperServiceProvider;
use App\Providers\NotificationServiceProvider;
use App\Providers\PostsHelperServiceProvider;
use App\Model\Gallery;
use App\Model\User;
use Carbon\Carbon;
use Cookie;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;;
use Illuminate\Support\ViewErrorBag;
use JavaScript;
use Log;
use View;
use Session;

class GallaryController extends Controller
{
    /**
     * Renders the post create page.
     *
     * @return \Illuminate\Contracts\View\Factory|\Illuminate\View\View
     */
    public function create()
    {
        return view('pages.gallary.create');
    }

    /**
     * Method used for creating / editing posts.
     *
     * @param SavePostRequest $request
     * @return \Illuminate\Http\JsonResponse
     */
    public function saveGallery(Request $request)
    {
        try {
            if (! GenericHelperServiceProvider::isUserVerified() && getSetting('site.enforce_user_identity_checks')) {
                return response()->json(['success' => false, 'errors' => ['permissions' => __('User not verified. Can not post content.')]], 500);
            }

        $validated = $request->validate([
            'image' => 'mimes:jpeg,jpg,png,gif|required',
        ]);

        $fileModel = new Gallery;

        if($request->file()) {
            $fileName = time().'_'.$request->file('image')->getClientOriginalName();
            $filePath = $request->file('image')->storeAs('gallery', $fileName, 'public');

            $fileModel->image = '/storage/' . $filePath;
            $fileModel->user_id = $request->user_id;
            $fileModel->save();

            return back()
            ->with('success','File has been uploaded.');
        }

        } catch (\Exception $exception) {
            return response()->json(['success' => false, 'errors' => [$exception->getMessage()]]);
        }

    }

    /**
     * Method used for deleting a post.
     *
     * @param DeletePostRequest $request
     * @return \Illuminate\Http\JsonResponse
     */
    public function gallerydelete(Request $request)
    {
        $id = $request->id;
        $image = Gallery::findOrFail($id);
        $image_path = public_path($image->image);
        if ($image_path) {
            //File::delete($image_path);
            unlink($image_path);
        }
        $image->delete();
        return back()->with('success','Image has been Deleted');
    }
}
