<?php

namespace App\Http\Controllers;

use App\Http\Requests\SaveNewContactMessageRequest;
use App\Model\ContactMessage;
use App\Model\Country;
use App\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\App;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Cache;
use App\Providers\EmailsServiceProvider;
use GuzzleHttp\Client;

class GenericController extends Controller
{
    /**
     * Show the application dashboard.
     *
     * @return \Illuminate\Contracts\Support\Renderable
     */
    public function countries()
    {
        return response()->json([
            'countries'=> Country::with(['taxes'])->get(),
        ]);
    }

    /**
     * Sets user locale.
     *
     * @param Request $request
     * @return \Illuminate\Http\RedirectResponse
     */
    public function setLanguage(Request $request)
    {
        $user = Auth::user();
        $user->settings = collect(array_merge($user->settings->toArray(), ['locale'=>$request->route('locale')]));
        $user->save();

        // Resetting cached translation files ( for frontend )
        App::setLocale(Auth::user()->settings['locale']);
        $langPath = resource_path('lang/'.Auth::user()->settings['locale']);
        if (env('APP_ENV') == 'production') {
            Cache::forget('translations');
            Cache::rememberForever('translations', function () use ($langPath) {
                return file_get_contents($langPath.'.json');
            });
        } else {
            Cache::forget('translations');
            Cache::remember('translations', 5, function () use ($langPath) {
                return file_get_contents($langPath.'.json');
            });
        }
        return redirect()->back();
    }

    public function contact(Request $request){
        return view('pages.contact', []);
    }

    public function sendContactMessage(SaveNewContactMessageRequest $request){

      $grecaptcha=$request->get('grecaptcha');

      $client = new client();

      $response = $client->post(
      	'https://www.google.com/recaptcha/api/siteverify',
      	['form_params'=>
      		[
      			'secret'=>'6Lc2vS0eAAAAAKI1wdhH6ibSXdSYCKx6bDaxK_yq',
      			'response'=>$grecaptcha
      		]
      	]
      );

      $body = json_decode((string)$response->getBody());

      if($body->success){
          ContactMessage::create([
              'email' => $request->get('email'),
              'subject' => $request->get('subject'),
              'message' => $request->get('message'),
          ]);

          // Sending out admin email
         $adminEmails = User::where('role_id', 1)->select(['email', 'name'])->get();
         foreach ($adminEmails as $user) {
             EmailsServiceProvider::sendGenericEmail(
                 [
                     'email' => $user->email,
                     'subject' => __('Action required | New Contact Message'),
                     'title' => __('Hello, :name,', ['name' => $user->name]),
                     'content' => __('There is a new Contact Message on :siteName that requires your attention.', ['siteName' => getSetting('site.name')]),
                     'button' => [
                         'text' => __('Go to admin'),
                         'url' => route('voyager.dashboard'),
                     ],
                 ]
             );
         }

        return back()->with('success', __('Message sent.'));
      }else{
        return back()->with('error', __('Recaptcha invalid'));
      }

    }

}
