<?php

namespace App\Providers;

use App\User;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\ServiceProvider;
use View;

class MembersHelperServiceProvider extends ServiceProvider
{
    /**
     * Register services.
     *
     * @return void
     */
    public function register()
    {
        //
    }

    /**
     * Bootstrap services.
     *
     * @return void
     */
    public function boot()
    {
        //
    }

    /**
     * Small method that tries to fetch up a list of the most popular profiles across the platform
     * If there isn't a big enough number to choose from, it fallbacks to latest profiles.
     *
     * @param bool $encodeToHtml
     * @param array $filters
     * @return mixed
     */
    public static function getSuggestedMembers($encodeToHtml = false, $filters = [])
    {

        // Get top 32 list of most subbed users
        $mostSubbedMax = (int) getSetting('feed.feed_suggestions_total_cards') * 3;
        $topSubbedUsers = DB::select("
            SELECT usersTable.id, COUNT(subsTable.id ) AS subs_count FROM users usersTable
            INNER JOIN subscriptions subsTable ON usersTable.id = subsTable.recipient_user_id
            WHERE usersTable.role_id = 2
            GROUP BY usersTable.id
            ORDER BY subs_count DESC
            LIMIT 0,{$mostSubbedMax}
        ");
        $topSubbedUsers = array_map(function ($v) {
            return $v->id;
        }, $topSubbedUsers);

        $members = User::limit(getSetting('feed.feed_suggestions_total_cards') * getSetting('feed.feed_suggestions_card_per_page'))->where('public_profile', 1);

        // If there are more than 9 users having subs, use those
        // Otherwise, grab latest 9 users by date
        if (count($topSubbedUsers) >= 9) {
            $members->whereIn('id', $topSubbedUsers);
        } else {
            $members->where('role_id',2);
            $members->orderByDesc('created_at');
            $members->where('id', '<>', Auth::user()->id);
        }

        // Filtering free/paid accounts
        if (isset($filters['free'])) {
            $members->where('profile_access_price', 0);
        }
        $members = $members->get();

        // Shuffle the list each time for more randomness
        $members = $members->shuffle();

        // Return either raw data to the views or json encoded, rendered views
        if ($encodeToHtml) {
            $membersData['html'] = View::make('elements.feed.suggestions-wrapper')->with('profiles', $members)->render();

            return $membersData;
        } else {
            return $members;
        }
    }

    /**
     * Returns a list of latest profiles.
     * @param $limit
     * @return mixed
     */
    public static function getFeaturedMembers()
    {
        $members = User::limit(6)->where('public_profile', 1)->where('role_id',2)->where('user_type','creator')->where('featured_creators','featured_creator')->orderByDesc('updated_at')->get();
        return $members;
    }
    public static function getisFeatured()
    {
        $members = User::limit(6)->where('public_profile', 1)->where('role_id',2)->where('user_type','creator')->where('is_featured',1)->orderByDesc('updated_at')->get();
        return $members;
    }
}
